# Misago PYPI Plugin

This repo contains a minimal Misago plugin used for testing Misago's support for installing plugins from PYPI through `pip-install.txt` file in `plugins` directory.

This plugin implements no logic, but it has a manifest and will be displayed properly on plugins list in Misago's admin panel.


Copyright and license
---------------------

**Misago** - Copyright © 2023 [Rafał Pitoń](http://github.com/rafalp)
This program comes with ABSOLUTELY NO WARRANTY.

This is a free software and you are welcome to modify and redistribute it under the conditions described in the license.
For the complete license, refer to the LICENSE file.